unit Unit1;

interface

uses
  Classes, SysUtils, IWAppForm, IWApplication, IWColor, IWTypes, Vcl.Controls,
  IWVCLBaseControl, IWBaseControl, IWBaseHTMLControl, IWControl, IWCompButton,
  UCustomFlexCelReport, UFlexCelReport, UExcelAdapter, XLSXAdapter,
  IWCompRadioButton, IWCompExtCtrls;

type

  TExportType = (
    et_Xls,
    et_Xlsx,
    et_Csv,
    et_Pdf,
    et_Html
  );

  TIWForm1 = class(TIWAppForm)
    IWButton1: TIWButton;
    XLSXAdapter1: TXLSXAdapter;
    FlexCelReport1: TFlexCelReport;
    IWRadioGroup1: TIWRadioGroup;
    cbXls: TIWRadioButton;
    cbXlsx: TIWRadioButton;
    cbCSV: TIWRadioButton;
    cbHTML: TIWRadioButton;
    cbPDF: TIWRadioButton;
    procedure IWButton1Click(Sender: TObject);
    procedure FlexCelReport1AfterGenerateWorkbook(Sender: TObject;
      const ExcelApp: TExcelFile);
  private
    MemStream: TMemoryStream;
    function GetExportType: TExportType;
    function GetExt: string;
  public
  end;

implementation
uses VCL.FlexCel.Core, FlexCel.XlsAdapter, FlexCel.Render, FlexCel.Pdf;

{$R *.dfm}

procedure ExportToHtml(const MemStream: TStream; const xls: TXlsFile);
var
  html: TFlexCelHtmlExport;
  sw: TStreamWriter;
begin
  html := TFlexCelHtmlExport.Create(xls, true);
  try
    sw := TStreamWriter.Create(MemStream);
    try
      html.ExportAllVisibleSheetsAsOneHtmlFile(sw, 'test.html', '', '', '-----------------');
    finally
      sw.Free;
    end;
  finally
    html.Free;
  end;
end;
procedure ExportToPdf(const MemStream: TStream; const xls: TXlsFile);
var
  pdf: TFlexCelPdfExport;
begin
  pdf := TFlexCelPdfExport.Create(xls, true);
  try
    pdf.Export(MemStream);
  finally
    pdf.Free;
  end;
end;

procedure ExportFile(const MemStream: TStream; const xls: FlexCel.XlsAdapter.TXlsFile; const ExportType: TExportType);
begin
  case ExportType of
    et_Xls: xls.Save(MemStream, TFileFormats.Xls);
    et_Xlsx: xls.Save(MemStream, TFileFormats.Xlsx);
    et_Csv: xls.Save(MemStream, TFileFormats.Text, ',', TEncoding.UTF8);
    et_Html: ExportToHtml(MemStream, xls);
    et_Pdf: ExportToPdf(MemStream, xls);
  end;

  MemStream.Position := 0;

end;

function TIWForm1.GetExportType: TExportType;
begin
  if cbXlsx.Checked then exit(et_Xlsx);
  if cbCSV.Checked then exit(et_Csv);
  if cbHTML.Checked then exit(et_Html);
  if cbPdf.Checked then exit(et_Pdf);

  Result := et_Xls;

end;

function TIWForm1.GetExt: string;
begin
  if cbXlsx.Checked then exit('.xlsx');
  if cbCSV.Checked then exit('.csv');
  if cbHTML.Checked then exit('.html');
  if cbPdf.Checked then exit('.pdf');

  Result := '.xls';

end;

procedure TIWForm1.FlexCelReport1AfterGenerateWorkbook(Sender: TObject;
  const ExcelApp: UExcelAdapter.TExcelFile);
var
  xls: FlexCel.XlsAdapter.TXlsFile;
begin
  xls := (ExcelApp as TXLSXFile).GetTWorkbook;
  MemStream.Free;
  MemStream := TMemoryStream.Create;

  ExportFile(MemStream, xls, GetExportType);
end;

procedure TIWForm1.IWButton1Click(Sender: TObject);
begin
  try
    FlexCelReport1.Values['test'] := 'Hello!';
    FlexCelReport1.Run;
    WebApplication.SendStream(MemStream, true, '', 'Deposits_selected' + GetExt);
    MemStream := nil;
  Except
    MemStream.Free;
    MemStream := nil;
    raise;
  end;
end;

initialization
  TIWForm1.SetAsMainForm;

end.
